#
# spec file for package gnome-contacts
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-contacts
Version:        3.26.1
Release:        lp151.2.3
Summary:        Contacts Manager for GNOME
License:        GPL-2.0+
Group:          Productivity/Office/Other
Url:            http://www.gnome.org
Source0:        http://download.gnome.org/sources/gnome-contacts/3.26/%{name}-%{version}.tar.xz

BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(champlain-0.12)
BuildRequires:  pkgconfig(cheese)
BuildRequires:  pkgconfig(cheese-gtk) >= 3.3.91
BuildRequires:  pkgconfig(clutter-gtk-1.0)
BuildRequires:  pkgconfig(folks) >= 0.11.4
BuildRequires:  pkgconfig(folks-eds)
BuildRequires:  pkgconfig(folks-telepathy)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(geocode-glib-1.0) >= 3.15.3
BuildRequires:  pkgconfig(glib-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(goa-1.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libebook-1.2) >= 3.13.90
BuildRequires:  pkgconfig(libedataserver-1.2) >= 3.13.90
BuildRequires:  pkgconfig(libedataserverui-1.2) >= 3.13.90
BuildRequires:  pkgconfig(telepathy-glib) >= 0.22.0
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires
%if !0%{?is_opensuse}
BuildRequires:  translation-update-upstream
%endif

%description
The Contacts Manager for GNOME

%package -n gnome-shell-search-provider-contacts
Summary:        Contacts Manager for GNOME -- Search Provider for GNOME Shell
Group:          Productivity/Office/Other
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    packageand(%{name}:gnome-shell)

%description -n gnome-shell-search-provider-contacts
The Contacts Manager for GNOME

This package contains a search provider to enable GNOME Shell to get
search results from contacts.

%lang_package

%prep
%autosetup -p1
%if !0%{?is_opensuse}
translation-update-upstream
%endif

%build
%{meson} \
	-D with-cheese=true \
	-D with-manpage=true \
	%{nil}
%{meson_build}

%install
%{meson_install}
%suse_update_desktop_file org.gnome.Contacts
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc NEWS README.md
%{_mandir}/man1/gnome-contacts.1%{ext_man}
%{_bindir}/gnome-contacts
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Contacts.appdata.xml
%{_datadir}/applications/org.gnome.Contacts.desktop
%{_datadir}/dbus-1/services/org.gnome.Contacts.service
%{_datadir}/glib-2.0/schemas/org.gnome.Contacts.gschema.xml
%{_datadir}/icons/hicolor/*/*/gnome-contacts*

%files -n gnome-shell-search-provider-contacts
%{_bindir}/gnome-contacts-search-provider
%{_datadir}/dbus-1/services/org.gnome.Contacts.SearchProvider.service

%files lang -f %{name}.lang

%changelog
* Wed Jan 24 2018 bjorn.lie@gmail.com
- Update to version 3.26.1:
  + Makefile.am: add README.md. Fixes bgo#792768.
  + Updated translations.
- Drop gnome-contacts-nb-translations.patch: Fixed upstream.
* Sun Dec 24 2017 zaitor@opensuse.org
- Add gnome-contacts-nb-translations.patch: Update Norwegian Bokmål
  translations.
- Use autosetup macro.
- Pass with-cheese=true and with-manpage=true to meson, ensure we
  build the feature we want.
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 3.26:
  + Fix crash if initial-setup == false (bgo#787450).
  + Updated translations.
* Tue Sep  5 2017 dimstar@opensuse.org
- Update to version 3.25.92.1:
  + Fix the schema: no longer depend on an inexisting enum.
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 3.25.92:
  + Added support for Flatpak.
  + Contacts can now be built with Meson.
  + Contacts now provides its own proper app icon.
  + Some labels in the contact sheet are now selectable.
  + Bug fixes:
  - Can't save notes in a contact.
  - Bumped minimal version of telepathy-glib, GTK+ and GLib.
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Run spec-cleaner, modernize spec.
- Stop exporting CFLAGS="%%{optflags} -w", not needed anymore,
  either fixed due to meson build, or in vala itself.
- Drop gnome-shell BuildRequires: It was only there for directory
  ownership, and that is no longer needed.
* Fri Jul 21 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Contacts now provides its own application icon.
  + Small UI improvements to the avatar chooser dialog.
  + Folks now requires version 11.4 or higher.
  + Migrated away from intltool and libgd.
  + Got rid of a bunch of warnings and critical messsages.
  + Use the locale to translate months.
- Drop obsolete clean section and post(un) handling, following
  macros dropped: glib2_gsettings_schema_post(un) and
  desktop_database_post(un), file-trigger takes care of this now.
- Drop intltool BuildRequires, no longer needed.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Add docbook-xsl-stylesheets, docbook_4 and xsltproc
  BuildRequires and pass --enable-man-pages=yes to configure, build
  manpages.
- Stop packaging AUTHORS ChangeLog COPYING and README, silence
  rpmlint, and they are in the src rpm anyway.
* Wed Sep 21 2016 dimstar@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Tue May 17 2016 zaitor@opensuse.org
- Update to version 3.20.0 (fate#318572):
  + Updated translations.
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
* Fri Feb 26 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Build fixes.
* Thu Feb 25 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Fixed minor bugs.
  + Updated translations.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Avoid crash in search provider.
  + Remove unused libnotify dependency.
  + Updated translations.
- Drop pkgconfig(libnotify) BuildRequires following upstream.
* Wed Sep 23 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Avoid dialogs from the search provider.
  + Fix desktop file category.
  + Support searching by phone number.
  + Updated translations.
* Wed Apr 22 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Bug fixed concerning Maps initialization.
* Thu Apr 16 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Updated translations.
* Sat Mar 21 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Fix syntax errors in desktop file keywords translations
    (bgo#736791).
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Finished Contacts - Maps integration.
- Add pkgconfig(libedataserverui-1.2) BuildRequires: new
  dependency.
* Tue Jan 27 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Added maps view for postal address.
- Add pkgconfig(champlain-0.12), pkgconfig(clutter-gtk-1.0) and
  pkgconfig(geocode-glib-1.0) BuildRequires: New dependencies.
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Remove unneeded logs in SearchProvider.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Adapt to gnome-shell's new search provider API.
* Tue Sep 16 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Fixed change address book bug.
* Tue Sep  2 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + AvatarDialog: Fix syntax error, Gtk.Stack has no
    set_current_page().
  + ContactEditor:
  - Ignore empty values for e-mail addresses, etc.
  - ContactEditor: Move string constants from Contact.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Added inline contact creation.
  + Updated Avatar dialog UI.
  + Improved Adwaita dark variant support.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Reworked setup view.
  + Reworked modes toggling (edit-mode, selection-mode).
  + Fixed birthday field bug.
  + Fixed link field bug.
  + Updated dialogs UI.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Sat Mar  1 2014 zaitor@opensuse.org
- Update to version 3.11.91:
  + Improved Linked Accounts dialog.
* Sun Feb 16 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Updated About dialog info.
  + Fixed email types in New Contact dialog.
  + Removed deprecated gtk+ calls.
  + Fixed minor bugs.
* Tue Oct 15 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Removed presence widget from ContactPane.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10:
  + Fixed shell-search-provider.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Added appdata description for Contacts.
  + Fixed look in RTL languages.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Ported to Gtk.Revealer.
  + Ported to Gtk.MenuButton.
  + Refined avatar size and name aligment.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Reworked UI to use custom titlebars.
  + Reworked select account dialog.
  + Fixed background colors all over.
  + Fixed "Select a Contact" view.
  + Updated to folks 0.9.5.
  + Migrated Contacts.Window to use Gtk+ templates.
  + Show all contacts everytime now.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Updated AddressBook dialog.
  + Updated Setup window.
  + Fixed in-app delete notification bug.
* Thu Jul 11 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Bugs fixed: bgo#679108, bgo#688341, bgo#696265, bgo#696272,
    bgo#698831, bgo#698893, bgo#699081, bgo#700729, bgo#700889,
    bgo#700959, bgo#701515, bgo#701535, bgo#702177, bgo#703470.
  + Updated translations.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Fixed "new" button height.
  + Fix webcam dialog shows blank camera.
  + Fix searching when string is empty.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fixed font color in contacts list.
  + Make changing birthdate work.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Thu Mar 14 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Animate toolbar transition in selection mode.
  + Updated translations.
* Fri Feb 22 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Added selection to contacts list.
  + Showing a contacts subset (main contacts vs all).
- Replace pkgconfig(gee-1.0) with pkgconfig(gee-0.8), following
  upstreams port to libgee 0.8.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Use libgd.
  + New contact pane design.
  + Fix build with new telepathy-glib.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires: new
  dependency.
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Keyboard shortcuts for new and help.
  + Add keywords to desktop file for better searching.
  + Updated translations.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Added help menu item.
* Mon Sep 17 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Use the new gstreamer 1.0 based libcheese
  + Always show search entry
  + Updated translations.
- Drop pkgconfig(gstreamer-interfaces-0.10) and
  pkgconfig(gstreamer-0.10) BuildRequires: configure no longer
  checks for gstreamer and relies entirely on cheese for this.
- Drop pkgconfig(gdk-x11-3.0) BuildRequires: no longer needed.
- Add pkgconfig(cheese) BuildRequires: mimic as closely as possible
  what configure does. In our packages this is currently implied
  by requiring cheese-gtk.
* Fri Sep  7 2012 vuntz@opensuse.org
- Create a gnome-shell-search-provider-contacts for the GNOME Shell
  search provider. It will automatically be installed if
  gnome-contacts and gnome-shell are installed.
- Add a gnome-shell BuildRequires for directory ownership.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Port the webcam support to libcheese
  + Upadted translations.
- Note: the port to libcheese does not infer changes in
  BuildRequires, as we already link against cheese and GStreamer.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + EggListBox converted from vala to C.
  + Fix icon for birthdays.
  + Minor notification themeing fixes.
  + Updated translations.
* Mon Jul 30 2012 dimstar@opensuse.org
- Update to version 3.5.4.1:
  + Rebuilding due to 3.5.4 being built with a broken libtool.
  + Bump libfolks dependency to 0.7.3.
* Sat Jul 28 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Use new libfolks API for Google address book system groups.
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Ship a search provider for the shell.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Use the new evolution-data-server APIs for addressbook
    configuration.
- Add pkgconfig(cheese-gtk) BuildRequires: new dependency.
* Fri Jun  8 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Make new avatars with webcam.
  + Fetch more contact info from telepathy.
  + Reimplement sidebar without using GtkTreeView.
- Add pkgconfig()-style BuildRequires: gdk-x11-3.0, gstreamer-0.10
  and gstreamer-interfaces-0.10: new dependencies.
* Tue May  1 2012 dimstar@opensuse.org
- Update to version 3.4.1:
  + Remove non-working reference to setting Avatar in new contact
    dialog.
  + Correct handling of detecting the main group of contacts in
    Google contacts.
  + Detect more facebook URIs.
  + Updated translations.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Updated translations.
* Mon Mar  5 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + Update the call support to work with latest Telepathy/Empathy
  + Allow linking non-primary contacts to each other and not only
    to primary ones
  + Fix crash in linking
  + Show unknown online status as offline
  + Updated translations.
- Add pkgconfig(telepathy-glib) BuildRequires: new dependency
  upstream.
* Mon Feb 20 2012 dimstar@opensuse.org
- Update to version 3.3.90:
  + New app icon
  + Support cropping of new avatars
  + Minor ui tweaks
  + Exit edit mode whe clicking outside edit widget
  + Add "Add to My contacts" button
  + Create google contacts in the "My contacts" group
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Moved custom CSS to Adwaita
  + Make clicking on edit rows work again
  + Remove initial letter column in lists
  + New look for link dialog
  + Hide search by default
  + Show google contacts that are not "My contacts" as as
    non-primary contacts
  + Make notifications animate in/out
  + Fix up minor UI details to better match new mockups
  + Better initial window size
  + Add inline link suggestions
  + Support undo for link/unlink
  + Delete works for more contacts
  + New first run dialog
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Use %%glib2_gsettings_schema_* macros for new GSettings schema.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add application menu
  + Support changing the address book
  + Only show primary contacts in the main list except when
    searching
  + Add toolbar in the new gnome 3 style
- Changes from (unreleased) version 3.3.2:
  + Polish details in the UI
  + Work with latest vala master
- Add new pkgconfig(folks-eds) BuildRequires, following upstream
  changes.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.1:
  + New design for the content pane
  + Undo and in-app notifications
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Fri Oct 21 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Fixed crashes
  + Fixed display name for Google contact sources
  + Add Unity to OnlyShowIn
  + Fix up spacing in contact pane
- Add pkgconfig(gee-1.0) BuildRequires: new dependency.
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0.1:
  + Fix label for local contacts
  + Fix video calls
- Changes from version 3.2.0:
  + Fix spacing due to GtkGrid API changes
  + Add quit and search keyboard shortcuts
  + Close error dialogs on response
  + Show birthdays with correct timezone
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 0.1.5.2:
  + Make GOA addressbooks default it there is no default
  + Make creating contacts on google work
- Changes from version 0.1.5.1:
  + Fix build issue
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 0.1.5:
  + Support linking and unlinking
  + Support linking suggestions
  + Don't require running evolution to pick up eds addressbooks
- Add new pkgconfig() BuildRequires: glib-2.0, goa-1.0,
  libebook-1.2, libedataserver-1.2. They are new dependencies
  upstream (the glib-2.0 one being now explicit, with a versioned
  dependency).
* Thu Sep  8 2011 vuntz@opensuse.org
- Update to version 0.1.4.1:
  + Fix crash
- Changes from version 0.1.4:
  + Unique application instance support
  + Support browsing for avatar file
  + Support deleting (some) contacts
  + Support linking contacts
  + Support for new fields:
  - nickname
  - birthday (readonly)
  - company/title/etc (readonly)
  + Lots of small UI tweaks
- Add pkgconfig(gnome-desktop-3.0) BuildRequires: new dependency.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 0.1.3:
  + Fix build due to libm missing
  + Lots of UI polish
  + Working contact editing
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 0.1.2:
  + Update to libfolks 0.6.0
  + Allow showing a contact from the commandline
* Fri Jul  1 2011 vuntz@opensuse.org
- Update to version 0.1.1:
  + Lots more work on the UI
  + Initial work on editing
- Add pkgconfig(libnotify) BuildRequires.
- Remove have_desktop_file and have_lang defines now that we have a
  .desktop file and translations.
* Wed Jun 15 2011 vuntz@opensuse.org
- Initial package (version 0.1.0).
